pub enum GraphDiscovery {
    V1,
    V2,
    Tenant(String),
}

Variants

V1

V2

Tenant(String)

Implementations

Get the URL for the public keys used by the Microsoft identity platform to sign security tokens.

Example
let url = GraphDiscovery::V1.url();
println!("{}", url);

Get the public keys used by the Microsoft identity platform to sign security tokens.

Example
let keys: serde_json::Value = GraphDiscovery::V1.signing_keys().unwrap();
println!("{:#?}", keys);

Get the public keys used by the Microsoft identity platform to sign security tokens.

Example
let keys: serde_json::Value = GraphDiscovery::V1.async_signing_keys().await.unwrap();
println!("{:#?}", keys);

Automatically convert the public keys used by the Microsoft identity platform to sign security tokens into an OAuth object. This will get the common urls for authorization and access tokens and insert them into OAuth.

Example
let oauth = GraphDiscovery::V1.oauth().unwrap();
println!("{:#?}", oauth);

Automatically convert the public keys used by the Microsoft identity platform to sign security tokens into an OAuth object. This will get the common urls for authorization and access tokens and insert them into OAuth.

Example
let oauth = GraphDiscovery::V1.async_oauth().await.unwrap();
println!("{:#?}", oauth);